default_app_config = 'djsingleton.apps.DjsingletonConfig'
__name__ = 'djsingleton'
__author__ = 'Neeraj Kumar'
__version__ = '1.1.0'
__author_email__ = 'sainineeraj1234@gmail.com'
__description__ = 'This is useful for create singleton model in django for make global settings.'
